@@ -1,11 +1,10 @@
-# Copyright 1999-2020 Gentoo Authors
+# Copyright 1999-2018 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
 import signal
 
 from portage import os
 from portage.util.futures import asyncio
-from portage.util.futures.compat_coroutine import coroutine, coroutine_return
 from portage.util.SlotObject import SlotObject
 
 class AsynchronousTask(SlotObject):
@@ -23,38 +22,12 @@ class AsynchronousTask(SlotObject):
 
 	_cancelled_returncode = - signal.SIGINT
 
-	@coroutine
-	def async_start(self):
-		try:
-			if self._was_cancelled():
-				raise asyncio.CancelledError
-			yield self._async_start()
-			if self._was_cancelled():
-				raise asyncio.CancelledError
-		except asyncio.CancelledError:
-			self.cancel()
-			self._was_cancelled()
-			self._async_wait()
-			raise
-		finally:
-			self._start_hook()
-
-	@coroutine
-	def _async_start(self):
-		self._start()
-		coroutine_return()
-		yield None
-
 	def start(self):
 		"""
 		Start an asynchronous task and then return as soon as possible.
 		"""
-		self._start()
 		self._start_hook()
-
-	def _start(self):
-		self.returncode = os.EX_OK
-		self._async_wait()
+		self._start()
 
 	def async_wait(self):
 		"""
@@ -76,6 +49,10 @@ class AsynchronousTask(SlotObject):
 			self._async_wait()
 		return waiter
 
+	def _start(self):
+		self.returncode = os.EX_OK
+		self._async_wait()
+
 	def isAlive(self):
 		return self.returncode is None
 
