@@ -70,11 +70,11 @@ class EbuildPhase(CompositeTask):
 	_locked_phases = ("setup", "preinst", "postinst", "prerm", "postrm")
 
 	def _start(self):
-		future = asyncio.ensure_future(self._async_start(), loop=self.scheduler)
+		future = asyncio.ensure_future(self._async_start(loop=self.scheduler), loop=self.scheduler)
 		self._start_task(AsyncTaskFuture(future=future), self._async_start_exit)
 
 	@coroutine
-	def _async_start(self):
+	def _async_start(self, loop=None):
 
 		need_builddir = self.phase not in EbuildProcess._phases_without_builddir
 
@@ -132,7 +132,7 @@ class EbuildPhase(CompositeTask):
 			# Force background=True for this header since it's intended
 			# for the log and it doesn't necessarily need to be visible
 			# elsewhere.
-			yield self._elog('einfo', msg, background=True)
+			yield self._elog('einfo', msg, background=True, loop=self.scheduler)
 
 		if self.phase == 'package':
 			if 'PORTAGE_BINPKG_TMPFILE' not in self.settings:
@@ -403,7 +403,7 @@ class EbuildPhase(CompositeTask):
 		self.wait()
 
 	@coroutine
-	def _elog(self, elog_funcname, lines, background=None):
+	def _elog(self, elog_funcname, lines, background=None, loop=None):
 		if background is None:
 			background = self.background
 		out = io.StringIO()
@@ -435,7 +435,7 @@ class EbuildPhase(CompositeTask):
 					log_file = build_logger.stdin
 
 				yield self.scheduler.async_output(msg, log_file=log_file,
-					background=background)
+					background=background, loop=self.scheduler)
 
 				if build_logger is not None:
 					build_logger.stdin.close()
@@ -487,7 +487,7 @@ class _PostPhaseCommands(CompositeTask):
 
 			if 'qa-unresolved-soname-deps' in self.settings.features:
 				# This operates on REQUIRES metadata generated by the above function call.
-				future = self._soname_deps_qa()
+				future = asyncio.ensure_future(self._soname_deps_qa(loop=self.scheduler), loop=self.scheduler)
 				# If an unexpected exception occurs, then this will raise it.
 				future.add_done_callback(lambda future: future.cancelled() or future.result())
 				self._start_task(AsyncTaskFuture(future=future), self._default_final_exit)
@@ -497,7 +497,7 @@ class _PostPhaseCommands(CompositeTask):
 			self._default_final_exit(task)
 
 	@coroutine
-	def _soname_deps_qa(self):
+	def _soname_deps_qa(self, loop=None):
 
 		vardb = QueryCommand.get_db()[self.settings['EROOT']]['vartree'].dbapi
 
@@ -512,4 +512,4 @@ class _PostPhaseCommands(CompositeTask):
 			qa_msg.extend("\t%s: %s" % (filename, " ".join(sorted(soname_deps)))
 				for filename, soname_deps in unresolved)
 			qa_msg.append("")
-			yield self.elog("eqawarn", qa_msg)
+			yield self.elog("eqawarn", qa_msg, loop=self.scheduler)
