@@ -5,7 +5,6 @@ from itertools import chain
 import warnings
 
 import portage
-from portage import _encodings, _unicode_decode, _unicode_encode
 from portage.cache.mappings import slot_dict_class
 from portage.const import EBUILD_PHASES
 from portage.dep import Atom, check_required_use, use_reduce, \
@@ -724,7 +723,8 @@ class Package(Task):
 			"""
 			if flag in self.all:
 				return flag
-			elif flag in self.all_aliases:
+
+			if flag in self.all_aliases:
 				for k, v in self.alias_mapping.items():
 					if flag in v:
 						return k
