@@ -26,7 +26,7 @@ from portage.versions import best, cpv_getversion
 from _emerge.Blocker import Blocker
 from _emerge.create_world_atom import create_world_atom
 from _emerge.resolver.output_helpers import ( _DisplayConfig, _tree_display,
-	_PackageCounters, _create_use_string, _calc_changelog, PkgInfo)
+	_PackageCounters, _create_use_string, PkgInfo)
 from _emerge.show_invalid_depstring_notice import show_invalid_depstring_notice
 
 class Display:
@@ -39,7 +39,6 @@ class Display:
 	"""
 
 	def __init__(self):
-		self.changelogs = []
 		self.print_msg = []
 		self.blockers = []
 		self.counters = _PackageCounters()
@@ -561,14 +560,6 @@ class Display:
 				noiselevel=-1)
 
 
-	def print_changelog(self):
-		"""Prints the changelog text to std_out
-		"""
-		for chunk in self.changelogs:
-			writemsg_stdout(chunk,
-				noiselevel=-1)
-
-
 	def get_display_list(self, mylist):
 		"""Determines the display list to process
 
@@ -668,23 +659,6 @@ class Display:
 		return pkg_info
 
 
-	def do_changelog(self, pkg, pkg_info):
-		"""Processes and adds the changelog text to the master text for output
-
-		@param pkg: _emerge.Package.Package instance
-		@param pkg_info: dictionay
-		Modifies self.changelogs
-		"""
-		if pkg_info.previous_pkg is not None:
-			ebuild_path_cl = pkg_info.ebuild_path
-			if ebuild_path_cl is None:
-				# binary package
-				ebuild_path_cl = self.portdb.findname(pkg.cpv, myrepo=pkg.repo)
-			if ebuild_path_cl is not None:
-				self.changelogs.extend(_calc_changelog(
-					ebuild_path_cl, pkg_info.previous_pkg, pkg.cpv))
-
-
 	def check_system_world(self, pkg):
 		"""Checks for any occurances of the package in the system or world sets
 
@@ -780,8 +754,6 @@ class Display:
 				pkg_info.attr_display.new_slot = True
 				if pkg_info.ordered:
 					self.counters.newslot += 1
-			if self.conf.changelog:
-				self.do_changelog(pkg, pkg_info)
 		else:
 			pkg_info.attr_display.new = True
 			if pkg_info.ordered:
@@ -909,8 +881,6 @@ class Display:
 							noiselevel=-1)
 			spawn_nofetch(self.conf.trees[pkg.root]["porttree"].dbapi,
 				pkg_info.ebuild_path)
-		if self.conf.changelog:
-			self.print_changelog()
 
 		return os.EX_OK
 
