@@ -1,8 +1,6 @@
 # Copyright 2013-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
-from __future__ import division
-
 import collections
 import errno
 import logging
@@ -230,12 +228,11 @@ class FetchTask(CompositeTask):
 		if self._fs_mirror_stack:
 			self._fetch_fs(self._fs_mirror_stack.pop())
 			return
-		else:
-			uri = self._next_uri()
-			if uri is not None:
-				self._tried_uris.add(uri)
-				self._fetch_uri(uri)
-				return
+		uri = self._next_uri()
+		if uri is not None:
+			self._tried_uris.add(uri)
+			self._fetch_uri(uri)
+			return
 
 		if self._tried_uris:
 			msg = "all uris failed"
@@ -350,14 +347,14 @@ class FetchTask(CompositeTask):
 					self.returncode = os.EX_OK
 					self.wait()
 					return
-				else:
-					self._start_task(
-						FileCopier(src_path=src, dest_path=dest,
-							background=(self.background and
-								self._log_path is not None),
-							logfile=self._log_path),
-						self._fs_mirror_copier_exit)
-					return
+
+				self._start_task(
+					FileCopier(src_path=src, dest_path=dest,
+						background=(self.background and
+							self._log_path is not None),
+						logfile=self._log_path),
+					self._fs_mirror_copier_exit)
+				return
 
 		self._try_next_mirror()
 
@@ -459,7 +456,7 @@ class FetchTask(CompositeTask):
 		if self._was_cancelled():
 			self.wait()
 			return
-		
+
 		if os.path.exists(self._fetch_tmp_file):
 			self._start_task(
 				FileDigester(file_path=self._fetch_tmp_file,
@@ -598,11 +595,10 @@ class FetchTask(CompositeTask):
 	def _select_hash(self):
 		if default_hash_name in self.digests:
 			return default_hash_name
-		else:
-			for hash_name in self.digests:
-				if hash_name != "size" and \
-					hash_name in portage.checksum.get_valid_checksum_keys():
-					return hash_name
+		for hash_name in self.digests:
+			if hash_name != "size" and \
+				hash_name in portage.checksum.get_valid_checksum_keys():
+				return hash_name
 
 		return None
 
