@@ -1,8 +1,6 @@
-# Copyright 2007-2019 Gentoo Authors
+# Copyright 2007-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
-from __future__ import print_function
-
 __all__ = ["SETPREFIX", "get_boolean", "SetConfigError",
 	"SetConfig", "load_default_config"]
 
@@ -29,12 +27,11 @@ SETPREFIX = "@"
 def get_boolean(options, name, default):
 	if not name in options:
 		return default
-	elif options[name].lower() in ("1", "yes", "on", "true"):
+	if options[name].lower() in ("1", "yes", "on", "true"):
 		return True
-	elif options[name].lower() in ("0", "no", "off", "false"):
+	if options[name].lower() in ("0", "no", "off", "false"):
 		return False
-	else:
-		raise SetConfigError(_("invalid value '%(value)s' for option '%(option)s'") % {"value": options[name], "option": name})
+	raise SetConfigError(_("invalid value '%(value)s' for option '%(option)s'") % {"value": options[name], "option": name})
 
 class SetConfigError(Exception):
 	pass
@@ -151,12 +148,12 @@ class SetConfig:
 		if not setname in self.psets:
 			options["name"] = setname
 			options["world-candidate"] = "False"
-			
+
 			# for the unlikely case that there is already a section with the requested setname
 			import random
 			while setname in parser.sections():
 				setname = "%08d" % random.randint(0, 10**10)
-			
+
 			parser.add_section(setname)
 			for k, v in options.items():
 				parser.set(setname, k, v)
@@ -201,7 +198,7 @@ class SetConfig:
 			optdict = {}
 			for oname in parser.options(sname):
 				optdict[oname] = parser.get(sname, oname)
-			
+
 			# create single or multiple instances of the given class depending on configuration
 			if parser.has_option(sname, "multiset") and \
 				parser.getboolean(sname, "multiset"):
@@ -246,7 +243,7 @@ class SetConfig:
 						"must be configured as multiset") % {"class": classname, "section": sname})
 					continue
 		self._parsed = True
-	
+
 	def getSets(self):
 		self._parse()
 		return self.psets.copy()
