@@ -42,9 +42,9 @@ import os as _os
 import traceback
 import warnings
 import errno
-import collections
 import functools
 
+import collections
 from collections import OrderedDict
 from urllib.parse import urlparse
 
@@ -220,7 +220,7 @@ class portdbapi(dbapi):
 		# instance that is passed in.
 		self.doebuild_settings = config(clone=self.settings)
 		self.depcachedir = os.path.realpath(self.settings.depcachedir)
-		
+
 		if os.environ.get("SANDBOX_ON") == "1":
 			# Make api consumers exempt from sandbox violations
 			# when doing metadata cache updates.
@@ -453,7 +453,7 @@ class portdbapi(dbapi):
 		return self.settings.repositories.ignored_repos
 
 	def findname2(self, mycpv, mytree=None, myrepo=None):
-		""" 
+		"""
 		Returns the location of the CPV, and what overlay it was in.
 		Searches overlays first, then PORTDIR; this allows us to return the first
 		matching file.  As opposed to starting in portdir and then doing overlays
@@ -822,7 +822,7 @@ class portdbapi(dbapi):
 				pkgdir, self.settings["DISTDIR"])
 		checksums = mf.getDigests()
 		if not checksums:
-			if debug: 
+			if debug:
 				writemsg(_("[empty/missing/bad digest]: %s\n") % (mypkg,))
 			return {}
 		filesdict={}
@@ -930,13 +930,12 @@ class portdbapi(dbapi):
 			return 0
 		if self.findname(cps[0] + "/" + cps2[1], myrepo=myrepo):
 			return 1
-		else:
-			return 0
+		return 0
 
 	def cp_all(self, categories=None, trees=None, reverse=False, sort=True):
 		"""
 		This returns a list of all keys in our tree or trees
-		@param categories: optional list of categories to search or 
+		@param categories: optional list of categories to search or
 			defaults to self.settings.categories
 		@param trees: optional list of trees to search the categories in or
 			defaults to self.porttrees
@@ -1315,7 +1314,7 @@ class portagetree:
 		settings=None):
 		"""
 		Constructor for a PortageTree
-		
+
 		@param root: deprecated, defaults to settings['ROOT']
 		@type root: String/Path
 		@param virtual: UNUSED
@@ -1497,7 +1496,7 @@ def _async_manifest_fetchlist(portdb, repo_config, cp, cpv_list=None,
 
 		if result.cancelled():
 			return
-		elif e is None:
+		if e is None:
 			result.set_result(dict((k, list(v.result()))
 				for k, v in zip(cpv_list, gather_result.result())))
 		else:
