@@ -215,14 +215,13 @@ def _lockfile_iteration(mypath, wantnewlockfile=False, unlinkfile=False,
 					if e.errno in (errno.ENOENT, errno.ESTALE):
 						os.close(myfd)
 						return None
-					else:
-						writemsg("%s: chown('%s', -1, %d)\n" % \
-							(e, lockfilename, portage_gid), noiselevel=-1)
-						writemsg(_("Cannot chown a lockfile: '%s'\n") % \
-							lockfilename, noiselevel=-1)
-						writemsg(_("Group IDs of current user: %s\n") % \
-							" ".join(str(n) for n in os.getgroups()),
-							noiselevel=-1)
+					writemsg("%s: chown('%s', -1, %d)\n" % \
+						(e, lockfilename, portage_gid), noiselevel=-1)
+					writemsg(_("Cannot chown a lockfile: '%s'\n") % \
+						lockfilename, noiselevel=-1)
+					writemsg(_("Group IDs of current user: %s\n") % \
+						" ".join(str(n) for n in os.getgroups()),
+						noiselevel=-1)
 		finally:
 			os.umask(old_mask)
 
@@ -442,10 +441,10 @@ def unlockfile(mytuple):
 	else:
 		raise InvalidData
 
-	if(myfd == HARDLINK_FD):
+	if myfd == HARDLINK_FD:
 		unhardlink_lockfile(lockfilename, unlinkfile=unlinkfile)
 		return True
-	
+
 	# myfd may be None here due to myfd = mypath in lockfile()
 	if isinstance(lockfilename, str) and \
 		not os.path.exists(lockfilename):
@@ -673,7 +672,7 @@ def hardlock_cleanup(path, remove_all_locks=False):
 				hostpid  = parts[1].split("-")
 				host  = "-".join(hostpid[:-1])
 				pid   = hostpid[-1]
-				
+
 				if filename not in mylist:
 					mylist[filename] = {}
 				if host not in mylist[filename]:
@@ -684,7 +683,7 @@ def hardlock_cleanup(path, remove_all_locks=False):
 
 
 	results.append(_("Found %(count)s locks") % {"count": mycount})
-	
+
 	for x in mylist:
 		if myhost in mylist[x] or remove_all_locks:
 			mylockname = hardlock_name(path + "/" + x)
