@@ -34,13 +34,11 @@ from portage.const import CACHE_PATH, \
 	PRIVATE_PATH, PROFILE_PATH, USER_CONFIG_PATH, \
 	USER_VIRTUALS_FILE
 from portage.dbapi import dbapi
-from portage.dbapi.porttree import portdbapi
 from portage.dep import Atom, isvalidatom, match_from_list, use_reduce, _repo_separator, _slot_separator
 from portage.eapi import (eapi_exports_AA, eapi_exports_merge_type,
 	eapi_supports_prefix, eapi_exports_replace_vars, _get_eapi_attrs)
 from portage.env.loaders import KeyValuePairFileLoader
-from portage.exception import InvalidDependString, IsADirectory, \
-		PortageException
+from portage.exception import InvalidDependString, PortageException
 from portage.localization import _
 from portage.output import colorize
 from portage.process import fakeroot_capable, sandbox_capable
@@ -97,12 +95,10 @@ def best_from_dict(key, top_dict, key_order, EmptyOnError=1, FullCopy=1, AllowEm
 		if x in top_dict and key in top_dict[x]:
 			if FullCopy:
 				return copy.deepcopy(top_dict[x][key])
-			else:
-				return top_dict[x][key]
+			return top_dict[x][key]
 	if EmptyOnError:
 		return ""
-	else:
-		raise KeyError("Key not found in list; '%s'" % key)
+	raise KeyError("Key not found in list; '%s'" % key)
 
 def _lazy_iuse_regex(iuse_implicit):
 	"""
@@ -2348,7 +2344,7 @@ class config:
 						if not x:
 							continue
 
-					if (x[0]=="-"):
+					if x[0] == "-":
 						myflags.discard(x[1:])
 						continue
 
@@ -2634,10 +2630,10 @@ class config:
 			# portage plans to update itself.
 			if mykey == "PORTAGE_BIN_PATH":
 				return portage._bin_path
-			elif mykey == "PORTAGE_PYM_PATH":
+			if mykey == "PORTAGE_PYM_PATH":
 				return portage._pym_path
 
-			elif mykey == "PORTAGE_PYTHONPATH":
+			if mykey == "PORTAGE_PYTHONPATH":
 				value = [x for x in \
 					self.backupenv.get("PYTHONPATH", "").split(":") if x]
 				need_pym_path = True
@@ -2651,7 +2647,7 @@ class config:
 					value.insert(0, portage._pym_path)
 				return ":".join(value)
 
-			elif mykey == "PORTAGE_GID":
+			if mykey == "PORTAGE_GID":
 				return "%s" % portage_gid
 
 		for d in self.lookuplist:
@@ -2694,7 +2690,7 @@ class config:
 	def __contains__(self, mykey):
 		"""Called to implement membership test operators (in and not in)."""
 		try:
-			 self._getitem(mykey)
+			self._getitem(mykey)
 		except KeyError:
 			return False
 		else:
@@ -2704,9 +2700,8 @@ class config:
 		v = self.get(k)
 		if v is not None:
 			return v
-		else:
-			self[k] = x
-			return x
+		self[k] = x
+		return x
 
 	def __iter__(self):
 		keys = set()
