@@ -871,7 +871,7 @@ class RepoConfigLoader:
 				continue
 			if repo.masters is None:
 				if self.mainRepo() and repo_name != self.mainRepo().name:
-					repo.masters = self.mainRepo(),
+					repo.masters = (self.mainRepo(),)
 				else:
 					repo.masters = ()
 			else:
@@ -968,8 +968,7 @@ class RepoConfigLoader:
 		main_repo = self.prepos['DEFAULT'].main_repo
 		if main_repo is not None and main_repo in self.prepos:
 			return self.prepos[main_repo].location
-		else:
-			return ''
+		return ''
 
 	def mainRepo(self):
 		"""Returns the main repo"""
