@@ -78,11 +78,11 @@ class BuildLogger(AsynchronousTask):
 		pipe_logger.start()
 
 		self._main_task_cancel = functools.partial(self._main_cancel, filter_proc, pipe_logger)
-		self._main_task = asyncio.ensure_future(self._main(filter_proc, pipe_logger), loop=self.scheduler)
+		self._main_task = asyncio.ensure_future(self._main(filter_proc, pipe_logger, loop=self.scheduler), loop=self.scheduler)
 		self._main_task.add_done_callback(self._main_exit)
 
 	@coroutine
-	def _main(self, filter_proc, pipe_logger):
+	def _main(self, filter_proc, pipe_logger, loop=None):
 		try:
 			if pipe_logger.poll() is None:
 				yield pipe_logger.async_wait()
