@@ -30,27 +30,27 @@ def urlopen(url, if_modified_since=None):
 	parse_result = urllib_parse.urlparse(url)
 	if parse_result.scheme not in ("http", "https"):
 		return _urlopen(url)
-	else:
-		netloc = parse_result.netloc.rpartition('@')[-1]
-		url = urllib_parse.urlunparse((parse_result.scheme, netloc, parse_result.path, parse_result.params, parse_result.query, parse_result.fragment))
-		password_manager = urllib_request.HTTPPasswordMgrWithDefaultRealm()
-		request = urllib_request.Request(url)
-		request.add_header('User-Agent', 'Gentoo Portage')
-		if if_modified_since:
-			request.add_header('If-Modified-Since', _timestamp_to_http(if_modified_since))
-		if parse_result.username is not None:
-			password_manager.add_password(None, url, parse_result.username, parse_result.password)
-		auth_handler = CompressedResponseProcessor(password_manager)
-		opener = urllib_request.build_opener(auth_handler)
-		hdl = opener.open(request)
-		if hdl.headers.get('last-modified', ''):
-			try:
-				add_header = hdl.headers.add_header
-			except AttributeError:
-				# Python 2
-				add_header = hdl.headers.addheader
-			add_header('timestamp', _http_to_timestamp(hdl.headers.get('last-modified')))
-		return hdl
+
+	netloc = parse_result.netloc.rpartition('@')[-1]
+	url = urllib_parse.urlunparse((parse_result.scheme, netloc, parse_result.path, parse_result.params, parse_result.query, parse_result.fragment))
+	password_manager = urllib_request.HTTPPasswordMgrWithDefaultRealm()
+	request = urllib_request.Request(url)
+	request.add_header('User-Agent', 'Gentoo Portage')
+	if if_modified_since:
+		request.add_header('If-Modified-Since', _timestamp_to_http(if_modified_since))
+	if parse_result.username is not None:
+		password_manager.add_password(None, url, parse_result.username, parse_result.password)
+	auth_handler = CompressedResponseProcessor(password_manager)
+	opener = urllib_request.build_opener(auth_handler)
+	hdl = opener.open(request)
+	if hdl.headers.get('last-modified', ''):
+		try:
+			add_header = hdl.headers.add_header
+		except AttributeError:
+			# Python 2
+			add_header = hdl.headers.addheader
+		add_header('timestamp', _http_to_timestamp(hdl.headers.get('last-modified')))
+	return hdl
 
 def _timestamp_to_http(timestamp):
 	dt = datetime.fromtimestamp(float(int(timestamp)+TIMESTAMP_TOLERANCE))
