@@ -39,7 +39,7 @@ class _Process:
 		return self._proc.returncode
 
 	@coroutine
-	def communicate(self, input=None): # pylint: disable=redefined-builtin
+	def communicate(self, input=None, loop=None): # pylint: disable=redefined-builtin
 		"""
 		Read data from stdout and stderr, until end-of-file is reached.
 		Wait for process to terminate.
@@ -49,13 +49,14 @@ class _Process:
 		@return: tuple (stdout_data, stderr_data)
 		@rtype: asyncio.Future (or compatible)
 		"""
+		loop = asyncio._wrap_loop(loop or self._loop)
 		futures = []
 		for input_file in (self._proc.stdout, self._proc.stderr):
 			if input_file is None:
-				future = self._loop.create_future()
+				future = loop.create_future()
 				future.set_result(None)
 			else:
-				future = _reader(input_file, loop=self._loop)
+				future = _reader(input_file, loop=loop)
 			futures.append(future)
 
 		writer = None
@@ -65,11 +66,11 @@ class _Process:
 			stdin = self._proc.stdin
 			stdin = os.fdopen(stdin, 'wb', 0) if isinstance(stdin, int) else stdin
 			_set_nonblocking(stdin.fileno())
-			writer = asyncio.ensure_future(_writer(stdin, input, loop=self._loop), loop=self._loop)
+			writer = asyncio.ensure_future(_writer(stdin, input, loop=loop), loop=loop)
 			writer.add_done_callback(lambda writer: stdin.close())
 
 		try:
-			yield asyncio.wait(futures + [self.wait()], loop=self._loop)
+			yield asyncio.wait(futures + [self.wait(loop=loop)], loop=loop)
 		finally:
 			if writer is not None:
 				if writer.done():
@@ -84,14 +85,15 @@ class _Process:
 
 		coroutine_return(tuple(future.result() for future in futures))
 
-	def wait(self):
+	def wait(self, loop=None):
 		"""
 		Wait for child process to terminate. Set and return returncode attribute.
 
 		@return: returncode
 		@rtype: asyncio.Future (or compatible)
 		"""
-		waiter = self._loop.create_future()
+		loop = asyncio._wrap_loop(loop or self._loop)
+		waiter = loop.create_future()
 		if self.returncode is None:
 			self._waiters.append(waiter)
 			waiter.add_done_callback(self._waiter_cancel)
