@@ -25,7 +25,7 @@
 ##
 ## This Python implementation is therefore also placed in the public domain.
 
-
+# pylint: disable=mixed-indentation
 
 #block_size = 64
 digest_size = 64
@@ -634,7 +634,6 @@ class WhirlpoolStruct:
 
 def WhirlpoolInit(ctx):
     ctx = WhirlpoolStruct()
-    return
 
 def WhirlpoolAdd(source, sourceBits, ctx):
     if not isinstance(source, bytes):
@@ -777,7 +776,6 @@ def processBuffer(ctx):
     # apply the Miyaguchi-Preneel compression function
     for i in range(8):
         ctx.hash[i] ^= state[i] ^ block[i]
-    return
 
 #
 # Tests.
